# pynetworks

A package that provides structure for networks of interconnected nodes using the DOT language for representation.

## Installation

**pynetworks** is published on PyPI, so it can be installed via pip.

`pip install pynetworks`

## Usage
